AiResource class
ai — generated.
Constructors
- AiResource(MisarMailClient client)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subjectLines(
{Map< String, dynamic> ? data}) → Future<Map< String, dynamic> > -
POST /ai/subject-lines -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited