CampaignsResource class

Constructors

CampaignsResource(MisarMailClient client)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Map<String, dynamic> data) Future<Map<String, dynamic>>
delete(String id) Future<Map<String, dynamic>>
get(String id) Future<Map<String, dynamic>>
list({Map<String, dynamic>? params}) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(String id) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited
update(String id, Map<String, dynamic> data) Future<Map<String, dynamic>>

Operators

operator ==(Object other) bool
The equality operator.
inherited