DeliverabilityResource class
deliverability — generated.
Constructors
- DeliverabilityResource(MisarMailClient client)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
audit(
) → Future< Map< String, dynamic> > -
GET /deliverability/audit -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
score(
) → Future< Map< String, dynamic> > -
GET /deliverability/score -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited