DmarcResource class
dmarc — generated.
Constructors
- DmarcResource(MisarMailClient client)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDomain(
{Map< String, dynamic> ? data}) → Future<Map< String, dynamic> > -
POST /dmarc/domains -
check(
{String? domain, String? dkim_selector}) → Future< Map< String, dynamic> > -
GET /dmarc/check -
listDomains(
) → Future< Map< String, dynamic> > -
GET /dmarc/domains -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeDomain(
{String? domain_id}) → Future< Map< String, dynamic> > -
DELETE /dmarc/domains -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited