EmailAccountsResource class

emailAccounts — generated.

Constructors

EmailAccountsResource(MisarMailClient client)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

list() Future<Map<String, dynamic>>
GET /email-accounts
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited