EmailsResource class

emails — generated.

Constructors

EmailsResource(MisarMailClient client)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String id) Future<Map<String, dynamic>>
GET /emails/:id
list({String? folder, String? search, int? limit}) Future<Map<String, dynamic>>
GET /emails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(String id, {Map<String, dynamic>? data}) Future<Map<String, dynamic>>
PATCH /emails/:id

Operators

operator ==(Object other) bool
The equality operator.
inherited