SubscriptionResource class

subscription — generated.

Constructors

SubscriptionResource(MisarMailClient client)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel({Map<String, dynamic>? data}) Future<Map<String, dynamic>>
DELETE /subscription
get({String? product}) Future<Map<String, dynamic>>
GET /subscription
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert({Map<String, dynamic>? data}) Future<Map<String, dynamic>>
POST /subscription

Operators

operator ==(Object other) bool
The equality operator.
inherited